@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::PerlTidy;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # ABSTRACT: PerlTidy in Dist::Zilla
 
@@ -60,17 +60,16 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
+
 __END__
 
-
-
 =head1 NAME
 
 Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -81,6 +80,27 @@ version 0.07
     [PerlTidy]
     perltidyrc = xt/.perltidyrc
 
+=head2 perltidyrc
+
+=head3 dist.ini
+
+    [PerlTidy]
+    perltidyrc = xt/.perltidyrc
+
+=head3 dzil config
+
+In your global dzil setting (which is '~/.dzil' or '~/.dzil/config.ini'), you can config the
+ perltidyrc like:
+
+    [PerlTidy]
+    perltidyrc = /home/fayland/somewhere/.perltidyrc
+
+=head3 ENV PERLTIDYRC
+
+If you do not config like above, we will fall back to ENV PERLTIDYRC
+
+    export PERLTIDYRC=/home/fayland/somwhere2/.perltidyrc
+
 =head1 AUTHOR
 
   Fayland Lam <fayland@gmail.com>
@@ -91,42 +111,3 @@ This software is copyright (c) 2009 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as perl itself.
-
-=head1 NAME
-
-Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
-
-=head1 perltidyrc
-
-=head2 dist.ini
-
-    [PerlTidy]
-    perltidyrc = xt/.perltidyrc
-
-=head2 dzil config
-
-In your global dzil setting (which is '~/.dzil' or '~/.dzil/config.ini'), you can config the
- perltidyrc like:
-
-    [PerlTidy]
-    perltidyrc = /home/fayland/somewhere/.perltidyrc
-
-=head2 ENV PERLTIDYRC
-
-If you do not config like above, we will fall back to ENV PERLTIDYRC
-
-    export PERLTIDYRC=/home/fayland/somwhere2/.perltidyrc
-
-=head1 AUTHOR
-
-Fayland Lam, C<< E<lt>fayland@gmail.comE<gt> >>
-
-=head1 COPYRIGHT
-
-Copyright 2009, Fayland Lam.
-
-This program is free software; you may redistribute it and/or modify it under
-the same terms as Perl itself.
-
-
-__END__
